@@ -78,8 +78,10 @@ computeAlignment :: OptionSet -> TestTree -> Int
 computeAlignment opts =
   fromMonoid .
   foldTestTree
-    (\_ name _ level -> Maximum (length name + level))
-    (\_ m -> m . (+ indentSize))
+    trivialFold
+      { foldSingle = \_ name _ level -> Maximum (length name + level)
+      , foldGroup = \_ m -> m . (+ indentSize)
+      }
     opts
   where
     fromMonoid m =
@@ -158,8 +160,10 @@ consoleTestReporter = TestReporter [] $ \opts tree -> Just $ \smap -> do
   st <-
     flip execStateT initialState $ getApp $ fst $
       foldTestTree
-        (runSingleTest smap)
-        runGroup
+        trivialFold
+          { foldSingle = runSingleTest smap
+          , foldGroup = runGroup
+          }
         opts
         tree
 
@@ -197,7 +201,7 @@ ok, fail, infoOk, infoFail :: (?colors :: Bool) => String -> IO ()
 fail     = output BoldIntensity   Vivid Red
 ok       = output NormalIntensity Dull  Green
 infoOk   = output NormalIntensity Dull  White
-infoFail = output NormalIntensity Dull  Black
+infoFail = output NormalIntensity Dull  Red
 
 output
   :: (?colors :: Bool)
