@@ -4,6 +4,10 @@ module Test.Tasty.Runners
     -- * Working with the test tree
     TestTree(..)
   , foldTestTree
+  , TreeFold(..)
+  , trivialFold
+  , AppMonoid(..)
+  , ResourceSpec(..)
     -- * Ingredients
   , Ingredient(..)
   , tryIngredients
@@ -22,6 +26,8 @@ module Test.Tasty.Runners
   , defaultMainWithIngredients
     -- * Running tests
   , Status(..)
+  , Result(..)
+  , Progress(..)
   , StatusMap
   , launchTestTree
   , NumThreads(..)
